==> node-webapp-0.0.3.tgz: package/lib/couchlib.js <==
/** 
 * @namespace 
 * @name couchlib 
*/

/** @lends couchlib */

var cradle = require('cradle');

/** Get a CouchDB connection. */
var get_couchdb_connection = function (couchdb_opts) {
  var my_opts = {
    host: couchdb_opts.host,
    port: couchdb_opts.port,
    options: {cache: couchdb_opts.cache, raw: false}
  };
  if (couchdb_opts.user.length > 0 && couchdb_opts.pass.length > 0) {
    my_opts['auth'] = {username: couchdb_opts.user, password: couchdb_opts.pass};
  }
  return new cradle.Connection(my_opts);
};
exports.get_couchdb_connection = get_couchdb_connection;
if (typeof process.singleton_schemas == 'undefined') {
  process.singleton_schemas = {};
}
/** Get a object for a CouchDB namespace. */
var get_couchdb_schema = function (couchdb_opts, schema) {
  if (couchdb_opts.prefix.length > 0) {
    var prefix = couchdb_opts.prefix + '_';
  } else {
    var prefix = '';
  }
  var k = couchdb_opts.host + '_' + couchdb_opts.port + '_' + prefix + schema;
  if (!process.singleton_schemas.hasOwnProperty(k)) {
    var c = get_couchdb_connection(couchdb_opts);
    process.singleton_schemas[k] = c.database(prefix + schema);
    process.singleton_schemas[k].exists(function (err, exist) {
      if (err) console.log('exists err: ' + err.toString());
      if (exist == false) {
        process.singleton_schemas[k].create(function (err, resp) {
          if (err) console.log('create err: ' + err.toString());
          else {
            if (couchdb_opts.views.hasOwnProperty(schema)) {
              for(var i in couchdb_opts.views[schema]) {
                (function () {
                  var view = couchdb_opts.views[schema][i];
                  process.singleton_schemas[k].save(view.uri, view.design, function (err, doc) {
                    console.log(view.uri);
                    console.log(err);
                    console.log(doc);
                  })
                })();
              }
            }
            
          }
        }); // create
      }
    }); // exists
  }
  return process.singleton_schemas[k];
};
exports.get_couchdb_schema = get_couchdb_schema;

/** Checks if a document exists. */
var check_object_exists = function (couchdb_opts, schema, name, cb) {
  var db = get_couchdb_schema(couchdb_opts, schema);
  db.get(name, function (err, doc) {
    if (err) {
      if (err.error == 'not_found') {
        cb(undefined, false);
      } else {
        cb(err, undefined);
      }
    } else {
      cb(undefined, true);
    }
  });
};
exports.check_object_exists = check_object_exists;

/** Saves a document after replacing a n properties. */
var merge_object = function (couchdb_opts, schema, name, props, cb) {
  var db = get_couchdb_schema(couchdb_opts, schema);
  db.get(name, function (err, doc) {
    if (err) {
      if (err.error == 'not_found') {
        cb({func: 'merge_object db.get_not_found', err: err}, undefined);
      } else {
        cb({func: 'merge_object db.get ', err: err}, undefined);
      }
    } else {
      var rev = doc._rev;
      delete doc._rev;
      delete doc._id;
      for (var i in props) {
        if (props.hasOwnProperty(i)) {
          doc[i] = props[i];
        }
      };
      db.save(name, rev, doc, function (err, resp) {
        if (err) {
          cb({func: 'merge_object db.save', err: err}, undefined);
        } else {
          cb(undefined, resp);
        }
      });
    }
  });
};
exports.merge_object = merge_object;

/** Saves a document after applying a method to the document. */
var meth_object = function (couchdb_opts, schema, name, meth, cb) {
  var db = get_couchdb_schema(couchdb_opts, schema);
  db.get(name, function (err, doc) {
    if (err) {
      if (err.error == 'not_found') {
        cb({func: 'meth_object db.get_not_found', err: err}, undefined);
      } else {
        cb({func: 'meth_object db.get ', err: err}, undefined);
      }
    } else {
      var rev = doc._rev;
      delete doc._id;
      delete doc._rev;
      db.save(name, rev, meth (doc), function (err, resp) {
        if (err) {
          cb({func: 'meth_object db.save', err: err}, undefined);
        } else {
          cb(undefined, resp);
        }
      });
    }
  });
};
exports.meth_object = meth_object;

==> node-webapp-0.0.4.tgz: package/lib/couchlib.js <==
/** 
 * @namespace 
 * @name couchlib 
*/

/** @lends couchlib */

var cradle = require('cradle');

/** Get a CouchDB connection. */
var get_couchdb_connection = function (couchdb_opts) {
  var my_opts = {
    host: couchdb_opts.host,
    port: couchdb_opts.port,
    options: {cache: couchdb_opts.cache, raw: false}
  };
  if (couchdb_opts.user.length > 0 && couchdb_opts.pass.length > 0) {
    my_opts['auth'] = {username: couchdb_opts.user, password: couchdb_opts.pass};
  }
  return new cradle.Connection(my_opts);
};
exports.get_couchdb_connection = get_couchdb_connection;
if (typeof process.singleton_schemas == 'undefined') {
  process.singleton_schemas = {};
}
/** Get a object for a CouchDB namespace. */
var get_couchdb_schema = function (couchdb_opts, schema) {
  if (couchdb_opts.prefix.length > 0) {
    var prefix = couchdb_opts.prefix + '_';
  } else {
    var prefix = '';
  }
  var k = couchdb_opts.host + '_' + couchdb_opts.port + '_' + prefix + schema;
  if (!process.singleton_schemas.hasOwnProperty(k)) {
    var c = get_couchdb_connection(couchdb_opts);
    process.singleton_schemas[k] = c.database(prefix + schema);
    process.singleton_schemas[k].exists(function (err, exist) {
      if (err) console.log('exists err: ' + err.toString());
      if (exist == false) {
        process.singleton_schemas[k].create(function (err, resp) {
          if (err) console.log('create err: ' + err.toString());
          else {
            if (couchdb_opts.hasOwnProperty('views') && couchdb_opts.views.hasOwnProperty(schema)) {
              for(var i in couchdb_opts.views[schema]) {
                (function () {
                  var view = couchdb_opts.views[schema][i];
                  process.singleton_schemas[k].save(view.uri, view.design, function (err, doc) {
                    if (err) console.log('Error: Create view failed for ' + view.url + ' with error: ' + err.toString());
                  })
                })();
              }
            }
            
          }
        });
      }
    });
  }
  return process.singleton_schemas[k];
};
exports.get_couchdb_schema = get_couchdb_schema;

/** Checks if a document exists. */
var check_object_exists = function (couchdb_opts, schema, name, cb) {
  var db = get_couchdb_schema(couchdb_opts, schema);
  db.get(name, function (err, doc) {
    if (err) {
      if (err.error == 'not_found') {
        cb(undefined, false);
      } else {
        cb(err, undefined);
      }
    } else {
      cb(undefined, true);
    }
  });
};
exports.check_object_exists = check_object_exists;

/** Saves a document after replacing a n properties. */
var merge_object = function (couchdb_opts, schema, name, props, cb) {
  var db = get_couchdb_schema(couchdb_opts, schema);
  db.get(name, function (err, doc) {
    if (err) {
      if (err.error == 'not_found') {
        cb({func: 'merge_object db.get_not_found', err: err}, undefined);
      } else {
        cb({func: 'merge_object db.get ', err: err}, undefined);
      }
    } else {
      var rev = doc._rev;
      delete doc._rev;
      delete doc._id;
      for (var i in props) {
        if (props.hasOwnProperty(i)) {
          doc[i] = props[i];
        }
      };
      db.save(name, rev, doc, function (err, resp) {
        if (err) {
          cb({func: 'merge_object db.save', err: err}, undefined);
        } else {
          cb(undefined, resp);
        }
      });
    }
  });
};
exports.merge_object = merge_object;

/** Saves a document after applying a method to the document. */
var meth_object = function (couchdb_opts, schema, name, meth, cb) {
  var db = get_couchdb_schema(couchdb_opts, schema);
  db.get(name, function (err, doc) {
    if (err) {
      if (err.error == 'not_found') {
        cb({func: 'meth_object db.get_not_found', err: err}, undefined);
      } else {
        cb({func: 'meth_object db.get ', err: err}, undefined);
      }
    } else {
      var rev = doc._rev;
      delete doc._id;
      delete doc._rev;
      db.save(name, rev, meth (doc), function (err, resp) {
        if (err) {
          cb({func: 'meth_object db.save', err: err}, undefined);
        } else {
          cb(undefined, resp);
        }
      });
    }
  });
};
exports.meth_object = meth_object;
